## This code creates the Evaluation and Management cohorts of adults (19-64)
## for the ADHD project.
#----------------------------------------------------------------------
# Install and load packages.

if (!require("pacman")) {
  install.packages("pacman")
  library(pacman)
}

p_load(data.table, collapse, ggplot2, fixest, stringr)
#----------------------------------------------------------------------
rm(list = ls())
setwd("/N/project/optum_freedman/INPC")


##----------------- Exposed Cohort 2019-2021

# 1) Open the demo data
demo = fread("../../../project/INPCC19Data/release_2022_02_12/csv/demo_1.csv")
demo2 = fread("../../../project/INPCC19Data/release_2022_02_12/csv/demo_2.csv")
demo = rbind(demo,demo2)
rm(demo2)

# Remove duplicates from the demographics file
demo = funique.data.frame(demo, cols = "STUDY_ID")

# Keep adults ages 19-64
demo[, age := lubridate::time_length(difftime("2020-12-31",DOB_PARSED),"years")]
demo <-subset(demo,age >= 19 & age <= 64)
demo$age = round(demo$age)

# 2) Read in the encounter file.
dt_enc = fread("../../../project/INPCC19Data/release_2022_02_12/csv/encounter_1.csv")
dt_enc2 = fread("../../../project/INPCC19Data/release_2022_02_12/csv/encounter_2.csv")
dt_enc = rbind(dt_enc,dt_enc2)
rm(dt_enc2)

# Limit to encounters with admission dates between Feb 2019 and Feb 2021
dt_enc = dt_enc[ADMIT_TIME_PARSED >= as.IDate("2019-02-01") &
                  ADMIT_TIME_PARSED <= as.IDate("2021-02-28")]

# Merge with the demographics data
dt_enc = merge(x = dt_enc, y = demo, by = "STUDY_ID")
dt_enc <- dt_enc[!(ENCOUNTER_ID=="0")]

# Keep sample of interest (Drop those without any encounter b/w Feb-June 2019)
dt_enc <- dt_enc[order(dt_enc$STUDY_ID,dt_enc$ADMIT_TIME_PARSED),]
dt_enc <- unique(dt_enc, by=c("STUDY_ID","ENCOUNTER_ID","ADMIT_TIME_PARSED"))
dt_enc[, one_enc := ifelse(ADMIT_TIME_PARSED >= as.IDate("2019-02-01") &
                             ADMIT_TIME_PARSED <= as.IDate("2019-06-30"), 1, 0)]
dt_enc[, keep_id := max(one_enc), by = "STUDY_ID"]
dt_enc <- dt_enc[!(keep_id==0)]   # Keep adults with at least one encounter b/w Feb-June
dt_enc = subset(dt_enc, select=-c(one_enc,keep_id))

# Export cohort dataset
df = funique.data.frame(dt_enc, cols = "STUDY_ID")
df = subset(df, select=-c(ENCOUNTER_ID,ADMIT_TIME,DISCHARGE_TIME,ENCOUNTER_TYPE,ADMIT_TIME_PARSED,
                          DISCHARGE_TIME_PARSED))
fwrite(df, file = "Extracts/cohort_adults_1921_exposed_inpc.csv")
rm(df)

# 3) Open diagnosis table and keep adult medical examinations

dx = fread("../../../project/INPCC19Data/release_2022_02_12/csv/dx_1.csv")
dx2 = fread("../../../project/INPCC19Data/release_2022_02_12/csv/dx_2.csv")
dx = rbind(dx,dx2)
rm(dx2)

# Remove the periods from the ICD-10 codes if there are any periods
dx[, dx_icd := str_replace_all(DX_CODE, "[.]", "")]

# Evaluation and Management CPT codes
eval_codes = c("Z000","Z0000","Z0001","Z008")

# Extract procedure codes and merge with encounter file
dx = dx[dx_icd %in% eval_codes]
dt_enc <- merge(x = dt_enc, y = dx, by = c("STUDY_ID","ENCOUNTER_ID"))
dt_enc <- unique(dt_enc, by=c("STUDY_ID","ENCOUNTER_ID","ADMIT_TIME_PARSED","dx_icd"))
rm(dx,demo)

# Order by STUDY_ID and ADMIT_DATE_PARSED
dt_enc <- dt_enc[order(dt_enc$STUDY_ID,dt_enc$ADMIT_TIME_PARSED),]

# Export dataset
fwrite(dt_enc, file = "Extracts/exposed_cpteval1921_adults_inpc.csv")


##----------------- Unexposed Cohort 2018-2020

# 1) Open the demo data
rm(list=ls())
demo = fread("../../../project/INPCC19Data/release_2022_02_12/csv/demo_1.csv")
demo2 = fread("../../../project/INPCC19Data/release_2022_02_12/csv/demo_2.csv")
demo = rbind(demo,demo2)
rm(demo2)

# Remove duplicates from the demographics file
demo = funique.data.frame(demo, cols = "STUDY_ID")

# Keep adults ages 19-64
demo[, age := lubridate::time_length(difftime("2020-12-31",DOB_PARSED),"years")]
demo <-subset(demo,age >= 19 & age <= 64)
demo$age = round(demo$age)

# 2) Read in the encounter file.
dt_enc = fread("../../../project/INPCC19Data/release_2022_02_12/csv/encounter_1.csv")
dt_enc2 = fread("../../../project/INPCC19Data/release_2022_02_12/csv/encounter_2.csv")
dt_enc = rbind(dt_enc,dt_enc2)
rm(dt_enc2)

# Limit to encounters with admission dates between Feb 2018 and Feb 2020
dt_enc = dt_enc[ADMIT_TIME_PARSED >= as.IDate("2018-02-01") &
                  ADMIT_TIME_PARSED <= as.IDate("2020-02-28")]

# Merge with the demographics data
dt_enc = merge(x = dt_enc, y = demo, by = "STUDY_ID")
dt_enc <- dt_enc[!(ENCOUNTER_ID=="0")]

# Keep sample of interest (Drop those without any encounter b/w Feb-June 2018)
dt_enc <- dt_enc[order(dt_enc$STUDY_ID,dt_enc$ADMIT_TIME_PARSED),]
dt_enc <- unique(dt_enc, by=c("STUDY_ID","ENCOUNTER_ID","ADMIT_TIME_PARSED"))
dt_enc[, one_enc := ifelse(ADMIT_TIME_PARSED >= as.IDate("2018-02-01") &
                             ADMIT_TIME_PARSED <= as.IDate("2018-06-30"), 1, 0)]
dt_enc[, keep_id := max(one_enc), by = "STUDY_ID"]
dt_enc <- dt_enc[!(keep_id==0)]   # Keep adults with at least one encounter b/w Feb-June
dt_enc = subset(dt_enc, select=-c(one_enc,keep_id))

# Export cohort dataset
df = funique.data.frame(dt_enc, cols = "STUDY_ID")
df = subset(df, select=-c(ENCOUNTER_ID,ADMIT_TIME,DISCHARGE_TIME,ENCOUNTER_TYPE,ADMIT_TIME_PARSED,
                          DISCHARGE_TIME_PARSED))
fwrite(df, file = "Extracts/cohort_adults_1820_unexposed_inpc.csv")
rm(df)

# 3) Open diagnosis table and keep adult medical examinations

dx = fread("../../../project/INPCC19Data/release_2022_02_12/csv/dx_1.csv")
dx2 = fread("../../../project/INPCC19Data/release_2022_02_12/csv/dx_2.csv")
dx = rbind(dx,dx2)
rm(dx2)

# Remove the periods from the ICD-10 codes if there are any periods
dx[, dx_icd := str_replace_all(DX_CODE, "[.]", "")]

# Evaluation and Management CPT codes
eval_codes = c("Z000","Z0000","Z0001","Z008")

# Extract procedure codes and merge with encounter file
dx = dx[dx_icd %in% eval_codes]
dt_enc <- merge(x = dt_enc, y = dx, by = c("STUDY_ID","ENCOUNTER_ID"))
dt_enc <- unique(dt_enc, by=c("STUDY_ID","ENCOUNTER_ID","ADMIT_TIME_PARSED","dx_icd"))
rm(dx,demo)

# Order by STUDY_ID and ADMIT_DATE_PARSED
dt_enc <- dt_enc[order(dt_enc$STUDY_ID,dt_enc$ADMIT_TIME_PARSED),]

# Export dataset
fwrite(dt_enc, file = "Extracts/unexposed_cpteval1820_adults_inpc.csv")
rm(list=ls())