# Optum DOD - Healthcare Extracts
# Individuals from 5 to 18 years old

library(arrow)
library(data.table)
library(fs)
library(plyr)
library(dplyr)
library(stringr)
library(xlsx)
library(haven)
library(zoo)
library("rio")

rm(list=ls())

#-------- Exposed Cohort 2019-2021 --------#

## Loop for diagnosis tables & physicians specialty

quart <- list("2019q1","2019q2","2019q3","2019q4","2020q1",
              "2020q2","2020q3","2020q4","2021q1")

for (i in quart) {
  
  # Open medical procedure table
  assign(paste0("med",i), fread(paste0("/N/project/optum/data/raw/dodr/dod_m",i,".txt.gz"), sep="|", header =TRUE, select =c("PATID","PAT_PLANID","CLMID","CLMSEQ","LOC_CD","FST_DT","PROC_CD","PROCMOD","PROCMOD2","PROCMOD3","PROCMOD4","POS","PROV","PROVCAT")))
  # Keep only CPT healthcare codes
  assign(paste0("med",i), subset(get(paste0("med",i)), PROC_CD == "99383" | PROC_CD == "99384" | PROC_CD == "99385" | PROC_CD == "99173" | PROC_CD == "99174" |
                                   PROC_CD == "99177" | PROC_CD == "92551" | PROC_CD == "92552" | PROC_CD == "92587" | PROC_CD == "96110" | PROC_CD == "96112" |
                                   PROC_CD == "90460" | PROC_CD == "90461" | PROC_CD == "99393" | PROC_CD == "99394" | PROC_CD == "99395"))
  
  # Merge Medical procedure and Provider bridge
  assign(paste0("prov_bridge"), fread(paste0("/N/project/optum/data/raw/dodr/dod_provider_bridge",".txt.gz"), sep="|", header =TRUE, select =c("PROV","PROV_UNIQUE","NPI")))
  assign(paste0("med",i), merge(get(paste0("med",i)),prov_bridge, by=c("PROV"), all.x=TRUE))
  rm(prov_bridge)
  
  # Merge Medical procedure and Provider
  assign(paste0("provider"), fread(paste0("/N/project/optum/data/raw/dodr/dod_provider",".txt.gz"), sep="|", header =TRUE, select =c("PROV_UNIQUE","GRP_PRACTICE","HOSP_AFFIL","PROV_STATE","PROV_TYPE","TAXONOMY1","TAXONOMY2")))
  assign(paste0("med",i), merge(get(paste0("med",i)),provider, by=c("PROV_UNIQUE"), all.x=TRUE))
  rm(provider)
}

# Append datasets by quarter
med1921 <- rbind(med2019q1,med2019q2,med2019q3,med2019q4,med2020q1,
                 med2020q2,med2020q3,med2020q4,med2021q1)
rm(med2019q1,med2019q2,med2019q3,med2019q4,med2020q1,
   med2020q2,med2020q3,med2020q4,med2021q1)

## Member continuous enrollment
members_co <-fread("/N/project/optum/data/raw/dodr/dod_mbr_co_enroll_r.txt.gz", 
                   sep="|", header =TRUE, select =c("PATID","YRDOB","ELIGEFF","ELIGEND","GDR_CD"))
# Keep eligible patients by enrollment date
members_co <- subset(members_co,ELIGEFF<="2019-02-01" & ELIGEND>="2021-03-31",select=PATID:GDR_CD)
# Keep sample of children between 5-18 years old
members_co <-subset(members_co,YRDOB>=2002 & YRDOB<=2015)

merged1921 <-merge(med1921,members_co, by="PATID")

## Create CPT dummies
merged1921$well_child_visit[merged1921$PROC_CD == "99383" | merged1921$PROC_CD == "99384" | merged1921$PROC_CD == "99385" | merged1921$PROC_CD == "99393" | merged1921$PROC_CD == "99394" | merged1921$PROC_CD == "99395"] <- 1
merged1921$immunization[merged1921$PROC_CD == "90460" | merged1921$PROC_CD == "90461"] <- 1
merged1921$hearing_test[merged1921$PROC_CD == "92551" | merged1921$PROC_CD == "92552" | merged1921$PROC_CD == "92587"] <- 1
merged1921$vision_test[merged1921$PROC_CD == "99173" | merged1921$PROC_CD == "99174" | merged1921$PROC_CD == "99177"] <- 1
merged1921$develop_screening[merged1921$PROC_CD == "96110" | merged1921$PROC_CD == "96112"] <- 1

merged1921$well_child_visit[is.na(merged1921$well_child_visit)] <- 0
merged1921$immunization[is.na(merged1921$immunization)] <- 0
merged1921$hearing_test[is.na(merged1921$hearing_test)] <- 0
merged1921$vision_test[is.na(merged1921$vision_test)] <- 0
merged1921$develop_screening[is.na(merged1921$develop_screening)] <- 0

## Telehealth Visits
merged1921[, visittype := case_when(PROCMOD == "95"~"TH",
                                    PROCMOD2 == "95"~"TH",
                                    PROCMOD3 == "95"~"TH",
                                    PROCMOD4 == "95"~"TH",
                                    POS == "02"~"TH",
                                    POS == "10"~"TH",
                                    TRUE~"InPerson")]

## Export file
export(merged1921,"/N/project/optum_freedman/Extracts/DOD/exposed_cpt1921_dod.csv")
rm(list=ls())


#-------- Unexposed Cohort 2018-2020 --------#

quart <-list("2018q1","2018q2","2018q3","2018q4","2019q1",
             "2019q2","2019q3","2019q4","2020q1")

for (i in quart) {
  
  # Open medical procedure table
  assign(paste0("med",i), fread(paste0("/N/project/optum/data/raw/dodr/dod_m",i,".txt.gz"), sep="|", header =TRUE, select =c("PATID","PAT_PLANID","CLMID","CLMSEQ","LOC_CD","FST_DT","PROC_CD","PROCMOD","PROCMOD2","PROCMOD3","PROCMOD4","POS","PROV","PROVCAT")))
  # Keep only CPT healthcare codes
  assign(paste0("med",i), subset(get(paste0("med",i)), PROC_CD == "99383" | PROC_CD == "99384" | PROC_CD == "99385" | PROC_CD == "99173" | PROC_CD == "99174" |
                                   PROC_CD == "99177" | PROC_CD == "92551" | PROC_CD == "92552" | PROC_CD == "92587" | PROC_CD == "96110" | PROC_CD == "96112" |
                                   PROC_CD == "90460" | PROC_CD == "90461" | PROC_CD == "99393" | PROC_CD == "99394" | PROC_CD == "99395"))
  
  # Merge Medical procedure and Provider bridge
  assign(paste0("prov_bridge"), fread(paste0("/N/project/optum/data/raw/dodr/dod_provider_bridge",".txt.gz"), sep="|", header =TRUE, select =c("PROV","PROV_UNIQUE","NPI")))
  assign(paste0("med",i), merge(get(paste0("med",i)),prov_bridge, by=c("PROV"), all.x=TRUE))
  rm(prov_bridge)
  
  # Merge Medical procedure and Provider
  assign(paste0("provider"), fread(paste0("/N/project/optum/data/raw/dodr/dod_provider",".txt.gz"), sep="|", header =TRUE, select =c("PROV_UNIQUE","GRP_PRACTICE","HOSP_AFFIL","PROV_STATE","PROV_TYPE","TAXONOMY1","TAXONOMY2")))
  assign(paste0("med",i), merge(get(paste0("med",i)),provider, by=c("PROV_UNIQUE"), all.x=TRUE))
  rm(provider)
}

# Append datasets by quarter
med1820 <- rbind(med2018q1,med2018q2,med2018q3,med2018q4,med2019q1,
                 med2019q2,med2019q3,med2019q4,med2020q1)
rm(med2018q1,med2018q2,med2018q3,med2018q4,med2019q1,
   med2019q2,med2019q3,med2019q4,med2020q1)

## Members continuous enrollment
members_co <-fread("/N/project/optum/data/raw/dodr/dod_mbr_co_enroll_r.txt.gz", sep="|", header =TRUE, select =c("PATID","YRDOB","ELIGEFF","ELIGEND","GDR_CD"))
# Keep eligible patients by enrollment date
members_co <- subset(members_co,ELIGEFF<="2018-02-01" & ELIGEND>="2020-03-31",select=PATID:GDR_CD)
# Keep sample of children between 5-18 years old
members_co <-subset(members_co,YRDOB>=2002 & YRDOB<=2015)

merged1820 <-merge(med1820,members_co, by="PATID")

## Create CPT dummies
merged1820$well_child_visit[merged1820$PROC_CD == "99383" | merged1820$PROC_CD == "99384" | merged1820$PROC_CD == "99385" | merged1820$PROC_CD == "99393" | merged1820$PROC_CD == "99394" | merged1820$PROC_CD == "99395"] <- 1
merged1820$immunization[merged1820$PROC_CD == "90460" | merged1820$PROC_CD == "90461"] <- 1
merged1820$hearing_test[merged1820$PROC_CD == "92551" | merged1820$PROC_CD == "92552" | merged1820$PROC_CD == "92587"] <- 1
merged1820$vision_test[merged1820$PROC_CD == "99173" | merged1820$PROC_CD == "99174" | merged1820$PROC_CD == "99177"] <- 1
merged1820$develop_screening[merged1820$PROC_CD == "96110" | merged1820$PROC_CD == "96112"] <- 1

merged1820$well_child_visit[is.na(merged1820$well_child_visit)] <- 0
merged1820$immunization[is.na(merged1820$immunization)] <- 0
merged1820$hearing_test[is.na(merged1820$hearing_test)] <- 0
merged1820$vision_test[is.na(merged1820$vision_test)] <- 0
merged1820$develop_screening[is.na(merged1820$develop_screening)] <- 0

## Telehealth Visits
merged1820[, visittype := case_when(PROCMOD == "95"~"TH",
                                    PROCMOD2 == "95"~"TH",
                                    PROCMOD3 == "95"~"TH",
                                    PROCMOD4 == "95"~"TH",
                                    POS == "02"~"TH",
                                    POS == "10"~"TH",
                                    TRUE~"InPerson")]

## Export file
export(merged1820,"/N/project/optum_freedman/Extracts/DOD/unexposed_cpt1820_dod.csv")
rm(list=ls())