***********************************
*Inputs: NHIS_Year_ADHD.dta and NHIS_2019.dta (two separate pulls from IPUMS)
*Output: Figure 1.pdf (ADHD diagnosis by group over time) and log file with sum stat for Table 1
***********************************

cap log close
log using "Table-1-NHIS.log", replace

*****************************************
*PART 1: Figure 1 
*****************************************

*read in IPUMS data pull and define key variables
clear
use "NHIS_Year_ADHD.dta"
keep year sampweight age sex racea hispyn hiprivatee addev
keep if addev==1 | addev==2

gen ADHDdx=(addev==2)
gen male=(sex==1)

gen race=""
replace race="white" if racea==100
replace race="black" if racea==200
replace race="asian" if racea>=400 & racea<=499
drop if racea>=900

drop if hispyn>2
gen hispanic=(hispyn==2)

gen race_ethnic=""
replace race_ethnic="hispanic" if hispanic==1
replace race_ethnic="white" if race=="white" & hispanic==0
replace race_ethnic="black" if race=="black" & hispanic==0
replace race_ethnic="asian" if race=="asian" & hispanic==0


*********
*plot trends in diagnosis rates over time 

drop sex
gen sex="Female"
replace sex="Male" if male==1

keep if race_ethnic!=""

collapse (mean) ADHDdx [aw=sampweight], by(year sex race_ethnic)

*********
*define moving average for smooth line trends 

egen panelid = group(sex race_ethnic), label
xtset panelid year

gen ADHDdx_ma = (F1.ADHDdx + F2.ADHDdx + ADHDdx + L1.ADHDdx + L2.ADHDdx) / 5
replace ADHDdx_ma = (F1.ADHDdx + F2.ADHDdx + ADHDdx ) / 3 if year==2000
replace ADHDdx_ma = (F1.ADHDdx + F2.ADHDdx + ADHDdx + L1.ADHDdx ) / 4 if year==2001
replace ADHDdx_ma = (F1.ADHDdx  + ADHDdx + L1.ADHDdx + L2.ADHDdx) / 4 if year==2018
replace ADHDdx_ma = (ADHDdx + L1.ADHDdx + L2.ADHDdx) / 3 if year==2019

set scheme s1mono
twoway line ADHDdx_ma year if race_ethnic=="white" ///
	|| line ADHDdx_ma year if race_ethnic=="hispanic" , lpattern(dash_dot)  ///
	|| line ADHDdx_ma year if race_ethnic=="black", lpattern(dash)  ///
	|| line ADHDdx_ma year if race_ethnic=="asian", lpattern(shortdash) /// 
	by(sex, note("", size(1))) ///
	ylabel(0(.02).20) ytitle("Ever Diagnosed ADHD (%)") xtitle("Year") ///
	legend(cols(4) order(1 "White" 2 "Hispanic" 3 "Black"  4 "Asian"))
graph export "figure-1.eps", replace

clear

*****************************************
*PART 2: Summary statistics for Table 1
*****************************************
use "NHIS_2019.dta"
keep wtfa_c agep_c sex_c hisp_c raceallp_c hispallp_c adhd* cover_c incgrp_c

*********
*identify children in sample (with private insurance, born between 2009 and 2015)
gen birth_year=2019-agep_c
gen private_ins=(cover_c==1)
gen public_ins=(cover_c==2)
gen priv_sample=(birth_year>=2009 & birth_year<2015 & private_ins==1)
gen full_sample=(birth_year>=2009 & birth_year<2015)

*********
*demographic variables
gen female=(sex_c==2)
replace female=. if !inlist(sex_c,1,2)

gen white=(hispallp_c==2)
gen black=(hispallp_c==3)
gen hispanic=(hispallp_c==1)
gen asian=(hispallp_c==4)
gen other=(white==0 & black==0 & hispanic==0 & asian==0)

gen low_inc=(incgrp_c<=3)

*********
*ADHD diagnosis if report currently having ADHD diagnosis
gen ADHDdx=(adhdnw_c==1)
replace ADHDdx=. if adhdnw_c==. & adhdev_c==.

*********
*summary stats private insurance
su female white black asian hispanic low_inc if priv_sample==1 [aw=wtfa_c]
bysort female: su ADHDdx if priv_sample==1 [aw=wtfa_c]

*********
*summary stats full sample
su female white black asian hispanic low_inc if full_sample==1 [aw=wtfa_c]
bysort female: su ADHDdx if full_sample==1 [aw=wtfa_c]




log close


